@@ -50,6 +50,7 @@
 package com.openexchange.mail.smal.impl.index;
 
 import java.io.Serializable;
+import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import com.openexchange.session.Session;
@@ -186,4 +187,9 @@ public final class FakeSession implements Session, Serializable {
         return false;
     }
 
+    @Override
+    public Set<String> getParameterNames() {
+        return parameters.keySet();
+    }
+
 }
